# Sequential list of commands used in the GWASpoly tutorial

require(GWASpoly)


# Read in data
TGall<-read.GWASpoly(ploidy=1,"TGphens.csv","TGgeno.csv","numeric",n.traits=10,delim=",")
TGkin<-read.GWASpoly(ploidy=1,"TGphens.csv","TGkin.csv","numeric",n.traits=10,delim=",")


# Calculate kinship 
TGall<-set.K(TGall) 
TGkin<-set.K(TGkin)
TGall@K[1:5,1:5]


# Examine population structure
plot(eigen(TGall@K)$values)			
plot(eigen(TGkin@K)$values)
plot(eigen(TGall@K)$vectors[,1:2])
plot(eigen(TGkin@K)$vectors[,1:2])

# Swap in kinship matrix calculated with thinned markers
TGanal<-TGall
TGanal@K<-TGkin@K

# check
TGanal@K[1:5,1:5]
TGkin@K[1:5,1:5]

# Do the GWAS
TG.GWAS<-GWASpoly(TGanal,models="additive")

# On HT and FT only
TG.Total<-GWASpoly(TGanal,models = "additive",traits = c("BLUE_YR","BLUE_DTH","BLUE_PH","BLUE_LOD","BLUE_GY","BLUE_TKW","BLUE_YC","BLUE_SV","BLUE_SDS","BLUE_GPC"))

# Examine results in various ways
manhattan.plot(TG.GWAS,trait=c("BLUE_YR"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_DTH"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_PH"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_LOD"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_GY"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_TKW"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_YC"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_SV"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_SDS"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)
manhattan.plot(TG.GWAS,trait=c("BLUE_GPC"),model="additive")
TG.GWAS<-set.threshold(TG.GWAS,method="Bonferroni",level=0.05)

# Run a permutation test with poor choice of parameters.
TG.perm<-set.threshold(TG.Total,method="permute",level=0.5,n.permute=10)



get.QTL(TG.GWAS)
get.QTL<-get.QTL(TG.GWAS,traits=c("BLUE_YR","BLUE_DTH","BLUE_PH","BLUE_LOD","BLUE_GY","BLUE_TKW","BLUE_YC","BLUE_SV","BLUE_SDS","BLUE_GPC"))
write.table(get.QTL,"QTL.txt")
boxplot(TGanal@pheno$BLUE_DTH~as.data.frame(TGanal@geno),varwidth=T) ## DUDA
qq.plot(TG.GWAS,trait="BLUE_YR",model="additive")
qq.plot(TG.GWAS,trait="BLUE_DTH",model="additive")
qq.plot(TG.GWAS,trait="BLUE_PH",model="additive")
qq.plot(TG.GWAS,trait="BLUE_LOD",model="additive")
qq.plot(TG.GWAS,trait="BLUE_GY",model="additive")
qq.plot(TG.GWAS,trait="BLUE_TKW",model="additive")
qq.plot(TG.GWAS,trait="BLUE_YC",model="additive")
qq.plot(TG.GWAS,trait="BLUE_SV",model="additive")
qq.plot(TG.GWAS,trait="BLUE_SDS",model="additive")
qq.plot(TG.GWAS,trait="BLUE_GPC",model="additive")

hist(10^(-TG.GWAS@scores[["BLUE_YR"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_DTH"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_PH"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_LOD"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_GY"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_TKW"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_YC"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_SV"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_SDS"]]),breaks=20)
hist(10^(-TG.GWAS@scores[["BLUE_GPC"]]),breaks=20)


# Do the analysis unadjusted for kinship
TGdiag<-TGanal
TGdiag@K<-diag(1,length(rownames(TGanal@geno)))
rownames(TGdiag@K)<-(rownames(TGanal@geno))
colnames(TGdiag@K)<-(rownames(TGanal@geno))

TGdiag@K[1:5,1:5]
TGdiag <-GWASpoly(TGdiag,models="additive")
TGdiag <-set.threshold(TGdiag,method="Bonferroni",level=0.05)
get.QTL2<-get.QTL(TGdiag,traits=c("BLUE_YR","BLUE_DTH","BLUE_PH","BLUE_LOD","BLUE_GY","BLUE_TKW","BLUE_YC","BLUE_SV","BLUE_SDS","BLUE_GPC"))
write.table(get.QTL2,"QTL2.txt")
manhattan.plot(TGdiag,trait=c("BLUE_YR"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_DTH"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_PH"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_LOD"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_GY"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_TKW"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_YC"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_SV"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_SDS"),model="additive")
manhattan.plot(TGdiag,trait=c("BLUE_GPC"),model="additive")

qq.plot(TGdiag,trait="BLUE_YR",model="additive")
qq.plot(TGdiag,trait="BLUE_DTH",model="additive")
qq.plot(TGdiag,trait="BLUE_PH",model="additive")
qq.plot(TGdiag,trait="BLUE_LOD",model="additive")
qq.plot(TGdiag,trait="BLUE_GY",model="additive")
qq.plot(TGdiag,trait="BLUE_TKW",model="additive")
qq.plot(TGdiag,trait="BLUE_YC",model="additive")
qq.plot(TGdiag,trait="BLUE_SV",model="additive")
qq.plot(TGdiag,trait="BLUE_SDS",model="additive")
qq.plot(TGdiag,trait="BLUE_GPC",model="additive")

hist(10^(-TGdiag@scores[["BLUE_YR"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_DTH"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_PH"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_LOD"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_GY"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_TKW"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_YC"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_SV"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_SDS"]]),breaks=20)
hist(10^(-TGdiag@scores[["BLUE_GPC"]]),breaks=20)

# Do GWAS adjusted for RHT2 as a covariate
summary(TGanal@fixed)
rht2<- set.params(fixed=c("Rht2_400"),fixed.type=c("numeric"))
TG.HT.rht2<-GWASpoly(TGanal,models="additive",trait=c("HT"),params=rht2)
TG.HT.rht2 <-set.threshold(TG.HT.rht2,method="Bonferroni",level=0.05)

# Compare results
get.QTL(TG.HT.rht2,traits=c("HT"))
get.QTL(TG.GWAS,traits=c("HT"))


# Do a Q+K analysis
params <- set.params(n.PC=10) 
TG.PCO<-GWASpoly(TGanal,models="additive",params=params)
TG.PCO<-set.threshold(TG.PCO,method="Bonferroni",level=0.05)
get.QTL3<-get.QTL(TG.PCO,traits=c("BLUE_YR","BLUE_DTH","BLUE_PH","BLUE_LOD","BLUE_GY","BLUE_TKW","BLUE_YC","BLUE_SV","BLUE_SDS","BLUE_GPC"))
write.table(get.QTL3,"QTL3.txt")

# Analyse with countries as a covariate
country<-set.params(fixed = "COUNTRY",fixed.type = "factor")
TG.country<-GWASpoly(TGanal,models="additive",params=country)